@@ -22,7 +22,7 @@
 #include <zend.h>
 #include <zend_vm_opcodes.h>
 
-static const char *zend_vm_opcodes_names[203] = {
+static const char *zend_vm_opcodes_names[210] = {
 	"ZEND_NOP",
 	"ZEND_ADD",
 	"ZEND_SUB",
@@ -102,7 +102,7 @@ static const char *zend_vm_opcodes_names[203] = {
 	"ZEND_UNSET_OBJ",
 	"ZEND_FE_RESET_R",
 	"ZEND_FE_FETCH_R",
-	"ZEND_EXIT",
+	NULL,
 	"ZEND_FETCH_R",
 	"ZEND_FETCH_DIM_R",
 	"ZEND_FETCH_OBJ_R",
@@ -226,9 +226,16 @@ static const char *zend_vm_opcodes_names[203] = {
 	"ZEND_FETCH_GLOBALS",
 	"ZEND_VERIFY_NEVER_TYPE",
 	"ZEND_CALLABLE_CONVERT",
+	"ZEND_BIND_INIT_STATIC_OR_JMP",
+	"ZEND_FRAMELESS_ICALL_0",
+	"ZEND_FRAMELESS_ICALL_1",
+	"ZEND_FRAMELESS_ICALL_2",
+	"ZEND_FRAMELESS_ICALL_3",
+	"ZEND_JMP_FRAMELESS",
+	"ZEND_INIT_PARENT_PROPERTY_HOOK_CALL",
 };
 
-static uint32_t zend_vm_opcodes_flags[203] = {
+static uint32_t zend_vm_opcodes_flags[210] = {
 	0x00000000,
 	0x00000b0b,
 	0x00000b0b,
@@ -299,7 +306,7 @@ static uint32_t zend_vm_opcodes_flags[203] = {
 	0x00001301,
 	0x0100a173,
 	0x01040300,
-	0x00000005,
+	0x00004005,
 	0x00186703,
 	0x00106703,
 	0x08000007,
@@ -356,7 +363,7 @@ static uint32_t zend_vm_opcodes_flags[203] = {
 	0x0000a103,
 	0x00002003,
 	0x03000001,
-	0x00000005,
+	0x00004005,
 	0x01000700,
 	0x00000000,
 	0x00000000,
@@ -410,9 +417,9 @@ static uint32_t zend_vm_opcodes_flags[203] = {
 	0x00047000,
 	0x00040000,
 	0x00067000,
-	0x00040373,
-	0x00100101,
+	0x00040b73,
 	0x00100101,
+	0x00100001,
 	0x00000101,
 	0x00001301,
 	0x00000101,
@@ -432,22 +439,29 @@ static uint32_t zend_vm_opcodes_flags[203] = {
 	0x00000101,
 	0x00000101,
 	0x00000101,
+	0x00002001,
+	0x00000101,
+	0x00000100,
+	0x00000000,
+	0x00000000,
+	0x01042003,
+	0x01001103,
 };
 
-ZEND_API const char* ZEND_FASTCALL zend_get_opcode_name(zend_uchar opcode) {
+ZEND_API const char* ZEND_FASTCALL zend_get_opcode_name(uint8_t opcode) {
 	if (UNEXPECTED(opcode > ZEND_VM_LAST_OPCODE)) {
 		return NULL;
 	}
 	return zend_vm_opcodes_names[opcode];
 }
-ZEND_API uint32_t ZEND_FASTCALL zend_get_opcode_flags(zend_uchar opcode) {
+ZEND_API uint32_t ZEND_FASTCALL zend_get_opcode_flags(uint8_t opcode) {
 	if (UNEXPECTED(opcode > ZEND_VM_LAST_OPCODE)) {
 		opcode = ZEND_NOP;
 	}
 	return zend_vm_opcodes_flags[opcode];
 }
-ZEND_API zend_uchar zend_get_opcode_id(const char *name, size_t length) {
-	zend_uchar opcode;
+ZEND_API uint8_t zend_get_opcode_id(const char *name, size_t length) {
+	uint8_t opcode;
 	for (opcode = 0; opcode < (sizeof(zend_vm_opcodes_names) / sizeof(zend_vm_opcodes_names[0])) - 1; opcode++) {
 		const char *opcode_name = zend_vm_opcodes_names[opcode];
 		if (opcode_name && strncmp(opcode_name, name, length) == 0) {
