@@ -83,18 +83,21 @@ const DATE_W3C = DATE_RFC3339;
 /**
  * @var int
  * @cvalue SUNFUNCS_RET_TIMESTAMP
+ * @deprecated
  */
 const SUNFUNCS_RET_TIMESTAMP = UNKNOWN;
 
 /**
  * @var int
  * @cvalue SUNFUNCS_RET_STRING
+ * @deprecated
  */
 const SUNFUNCS_RET_STRING = UNKNOWN;
 
 /**
  * @var int
  * @cvalue SUNFUNCS_RET_DOUBLE
+ * @deprecated
  */
 const SUNFUNCS_RET_DOUBLE = UNKNOWN;
 
@@ -120,14 +123,14 @@ function checkdate(int $month, int $day, int $year): bool {}
 
 /**
  * @refcount 1
- * @deprecated
  */
+#[\Deprecated(since: '8.1', message: 'use IntlDateFormatter::format() instead')]
 function strftime(string $format, ?int $timestamp = null): string|false {}
 
 /**
  * @refcount 1
- * @deprecated
  */
+#[\Deprecated(since: '8.1', message: 'use IntlDateFormatter::format() instead')]
 function gmstrftime(string $format, ?int $timestamp = null): string|false {}
 
 function time(): int {}
@@ -260,8 +263,8 @@ function date_default_timezone_get(): string {}
 
 /**
  * @refcount 1
- * @deprecated
  */
+#[\Deprecated(since: '8.1', message: 'use date_sun_info() instead')]
 function date_sunrise(
     int $timestamp, int $returnFormat = SUNFUNCS_RET_STRING,
     ?float $latitude = null, ?float $longitude = null, ?float $zenith = null,
@@ -269,8 +272,8 @@ function date_sunrise(
 
 /**
  * @refcount 1
- * @deprecated
  */
+#[\Deprecated(since: '8.1', message: 'use date_sun_info() instead')]
 function date_sunset(
     int $timestamp, int $returnFormat = SUNFUNCS_RET_STRING,
     ?float $latitude = null, ?float $longitude = null, ?float $zenith = null,
@@ -284,34 +287,34 @@ function date_sun_info(int $timestamp, float $latitude, float $longitude): array
 
 interface DateTimeInterface
 {
-    /** @var string */
-    public const ATOM = DATE_ATOM;
-    /** @var string */
-    public const COOKIE = DATE_COOKIE;
-    /** @var string */
-    public const ISO8601 = DATE_ISO8601;
-    /** @var string */
-    public const ISO8601_EXPANDED = DATE_ISO8601_EXPANDED;
-    /** @var string */
-    public const RFC822 = DATE_RFC822;
-    /** @var string */
-    public const RFC850 = DATE_RFC850;
-    /** @var string */
-    public const RFC1036 = DATE_RFC1036;
-    /** @var string */
-    public const RFC1123 = DATE_RFC1123;
-    /** @var string */
-    public const RFC7231 = DATE_RFC7231;
-    /** @var string */
-    public const RFC2822 = DATE_RFC2822;
-    /** @var string */
-    public const RFC3339 = DATE_RFC3339;
-    /** @var string */
-    public const RFC3339_EXTENDED = DATE_RFC3339_EXTENDED;
-    /** @var string */
-    public const RSS = DATE_RSS;
-    /** @var string */
-    public const W3C = DATE_W3C;
+
+    public const string ATOM = DATE_ATOM;
+
+    public const string COOKIE = DATE_COOKIE;
+
+    public const string ISO8601 = DATE_ISO8601;
+
+    public const string ISO8601_EXPANDED = DATE_ISO8601_EXPANDED;
+
+    public const string RFC822 = DATE_RFC822;
+
+    public const string RFC850 = DATE_RFC850;
+
+    public const string RFC1036 = DATE_RFC1036;
+
+    public const string RFC1123 = DATE_RFC1123;
+
+    public const string RFC7231 = DATE_RFC7231;
+
+    public const string RFC2822 = DATE_RFC2822;
+
+    public const string RFC3339 = DATE_RFC3339;
+
+    public const string RFC3339_EXTENDED = DATE_RFC3339_EXTENDED;
+
+    public const string RSS = DATE_RSS;
+
+    public const string W3C = DATE_W3C;
 
     /** @tentative-return-type */
     public function format(string $format): string;
@@ -325,6 +328,8 @@ interface DateTimeInterface
     /** @tentative-return-type */
     public function getTimestamp(): int;
 
+    public function getMicrosecond(): int;
+
     /** @tentative-return-type */
     public function diff(DateTimeInterface $targetObject, bool $absolute = false): DateInterval;
 
@@ -362,6 +367,9 @@ class DateTime implements DateTimeInterface
      */
     public static function createFromFormat(string $format, string $datetime, ?DateTimeZone $timezone = null): DateTime|false {}
 
+    /** @tentative-return-type */
+    public static function createFromTimestamp(int|float $timestamp): static {}
+
     /**
      * @return array<string, int|array>|false
      * @tentative-return-type
@@ -378,7 +386,7 @@ class DateTime implements DateTimeInterface
     /**
      * @tentative-return-type
      */
-    public function modify(string $modifier): DateTime|false {}
+    public function modify(string $modifier): DateTime {}
 
     /**
      * @tentative-return-type
@@ -409,6 +417,8 @@ class DateTime implements DateTimeInterface
      */
     public function getOffset(): int {}
 
+    public function getMicrosecond(): int {}
+
     /**
      * @tentative-return-type
      * @alias date_time_set
@@ -433,6 +443,8 @@ class DateTime implements DateTimeInterface
      */
     public function setTimestamp(int $timestamp): DateTime {}
 
+    public function setMicrosecond(int $microsecond): static {}
+
     /**
      * @tentative-return-type
      * @alias date_timestamp_get
@@ -466,6 +478,9 @@ class DateTimeImmutable implements DateTimeInterface
      */
     public static function createFromFormat(string $format, string $datetime, ?DateTimeZone $timezone = null): DateTimeImmutable|false {}
 
+    /** @tentative-return-type */
+    public static function createFromTimestamp(int|float $timestamp): static {}
+
     /**
      * @return array<string, int|array>|false
      * @tentative-return-type
@@ -497,6 +512,11 @@ class DateTimeImmutable implements DateTimeInterface
      */
     public function getTimestamp(): int {}
 
+    /**
+     * @alias DateTime::getMicrosecond
+     */
+    public function getMicrosecond(): int {}
+
     /**
      * @tentative-return-type
      * @alias date_diff
@@ -504,7 +524,7 @@ class DateTimeImmutable implements DateTimeInterface
     public function diff(DateTimeInterface $targetObject, bool $absolute = false): DateInterval {}
 
     /** @tentative-return-type */
-    public function modify(string $modifier): DateTimeImmutable|false {}
+    public function modify(string $modifier): DateTimeImmutable {}
 
     /** @tentative-return-type */
     public function add(DateInterval $interval): DateTimeImmutable {}
@@ -527,6 +547,8 @@ class DateTimeImmutable implements DateTimeInterface
     /** @tentative-return-type */
     public function setTimestamp(int $timestamp): DateTimeImmutable {}
 
+    public function setMicrosecond(int $microsecond): static {}
+
     /** @tentative-return-type */
     public static function createFromMutable(DateTime $object): static {}
 
@@ -536,76 +558,34 @@ class DateTimeImmutable implements DateTimeInterface
 
 class DateTimeZone
 {
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_AFRICA
-     */
-    public const AFRICA = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_AMERICA
-     */
-    public const AMERICA = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_ANTARCTICA
-     */
-    public const ANTARCTICA = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_ARCTIC
-     */
-    public const ARCTIC = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_ASIA
-     */
-    public const ASIA = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_ATLANTIC
-     */
-    public const ATLANTIC = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_AUSTRALIA
-     */
-    public const AUSTRALIA = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_EUROPE
-     */
-    public const EUROPE = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_INDIAN
-     */
-    public const INDIAN = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_PACIFIC
-     */
-    public const PACIFIC = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_UTC
-     */
-    public const UTC = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_ALL
-     */
-    public const ALL = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_GROUP_ALL_W_BC
-     */
-    public const ALL_WITH_BC = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_TIMEZONE_PER_COUNTRY
-     */
-    public const PER_COUNTRY = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_AFRICA */
+    public const int AFRICA = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_AMERICA */
+    public const int AMERICA = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_ANTARCTICA */
+    public const int ANTARCTICA = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_ARCTIC */
+    public const int ARCTIC = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_ASIA */
+    public const int ASIA = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_ATLANTIC */
+    public const int ATLANTIC = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_AUSTRALIA */
+    public const int AUSTRALIA = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_EUROPE */
+    public const int EUROPE = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_INDIAN */
+    public const int INDIAN = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_PACIFIC */
+    public const int PACIFIC = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_UTC */
+    public const int UTC = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_ALL */
+    public const int ALL = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_GROUP_ALL_W_BC */
+    public const int ALL_WITH_BC = UNKNOWN;
+    /** @cvalue PHP_DATE_TIMEZONE_PER_COUNTRY */
+    public const int PER_COUNTRY = UNKNOWN;
 
     public function __construct(string $timezone) {}
 
@@ -667,7 +647,7 @@ class DateInterval
     /**
      * @tentative-return-type
      */
-    public static function createFromDateString(string $datetime): DateInterval|false {}
+    public static function createFromDateString(string $datetime): DateInterval {}
 
     /**
      * @tentative-return-type
@@ -688,16 +668,10 @@ class DateInterval
 
 class DatePeriod implements IteratorAggregate
 {
-    /**
-     * @var int
-     * @cvalue PHP_DATE_PERIOD_EXCLUDE_START_DATE
-     */
-    public const EXCLUDE_START_DATE = UNKNOWN;
-    /**
-     * @var int
-     * @cvalue PHP_DATE_PERIOD_INCLUDE_END_DATE
-     */
-    public const INCLUDE_END_DATE = UNKNOWN;
+    /** @cvalue PHP_DATE_PERIOD_EXCLUDE_START_DATE */
+    public const int EXCLUDE_START_DATE = UNKNOWN;
+    /** @cvalue PHP_DATE_PERIOD_INCLUDE_END_DATE */
+    public const int INCLUDE_END_DATE = UNKNOWN;
 
     /** @readonly */
     public ?DateTimeInterface $start;
