@@ -35,51 +35,51 @@ namespace PHP {
 
 		CodePointBreakIterator& operator=(const CodePointBreakIterator& that);
 
-		virtual ~CodePointBreakIterator();
+		~CodePointBreakIterator() override;
 
 #if U_ICU_VERSION_MAJOR_NUM >= 70
-		virtual bool operator==(const BreakIterator& that) const;
+		bool operator==(const BreakIterator& that) const override;
 #else
-		virtual UBool operator==(const BreakIterator& that) const;
+		UBool operator==(const BreakIterator& that) const override;
 #endif
 
-		virtual CodePointBreakIterator* clone(void) const;
+		CodePointBreakIterator* clone(void) const override;
 
-		virtual UClassID getDynamicClassID(void) const;
+		UClassID getDynamicClassID(void) const override;
 
-		virtual CharacterIterator& getText(void) const;
+		CharacterIterator& getText(void) const override;
 
-		virtual UText *getUText(UText *fillIn, UErrorCode &status) const;
+		UText *getUText(UText *fillIn, UErrorCode &status) const override;
 
-		virtual void setText(const UnicodeString &text);
+		void setText(const UnicodeString &text) override;
 
-		virtual void setText(UText *text, UErrorCode &status);
+		void setText(UText *text, UErrorCode &status) override;
 
-		virtual void adoptText(CharacterIterator* it);
+		void adoptText(CharacterIterator* it) override;
 
-		virtual int32_t first(void);
+		int32_t first(void) override;
 
-		virtual int32_t last(void);
+		int32_t last(void) override;
 
-		virtual int32_t previous(void);
+		int32_t previous(void) override;
 
-		virtual int32_t next(void);
+		int32_t next(void) override;
 
-		virtual int32_t current(void) const;
+		int32_t current(void) const override;
 
-		virtual int32_t following(int32_t offset);
+		int32_t following(int32_t offset) override;
 
-		virtual int32_t preceding(int32_t offset);
+		int32_t preceding(int32_t offset) override;
 
-		virtual UBool isBoundary(int32_t offset);
+		UBool isBoundary(int32_t offset) override;
 
-		virtual int32_t next(int32_t n);
+		int32_t next(int32_t n) override;
 
-		virtual CodePointBreakIterator *createBufferClone(void *stackBuffer,
+		CodePointBreakIterator *createBufferClone(void *stackBuffer,
 														  int32_t &BufferSize,
-														  UErrorCode &status);
+														  UErrorCode &status) override;
 
-		virtual CodePointBreakIterator &refreshInputText(UText *input, UErrorCode &status);
+		CodePointBreakIterator &refreshInputText(UText *input, UErrorCode &status) override;
 
 		inline UChar32 getLastCodePoint()
 		{
