@@ -413,7 +413,8 @@ static bool ir_split_partially_dead_node(ir_ctx *ctx, ir_ref ref, uint32_t b)
 	n = ctx->use_lists[ref].refs;
 	for (i = 0; i < clones_count; i++) {
 		clone = clones[i].ref;
-		if (clones[i].use_count == 1
+		if (clones[i].block
+		 && clones[i].use_count == 1
 		 && ctx->cfg_blocks[clones[i].block].loop_depth >= ctx->cfg_blocks[uses[clones[i].use].block].loop_depth) {
 			/* TOTALLY_USEFUL block may be a head of a diamond above the real usage.
 			 * Sink it down to the real usage block.
@@ -1007,7 +1008,11 @@ int ir_schedule(ir_ctx *ctx)
 		start = i = bb->start;
 		_xlat[i] = bb->start = insns_count;
 		insn = &ctx->ir_base[i];
-		if (insn->op == IR_CASE_VAL) {
+		if (insn->op == IR_BEGIN) {
+			if (insn->op2) {
+				consts_count += ir_count_constant(_xlat, insn->op2);
+			}
+		} else if (insn->op == IR_CASE_VAL) {
 			IR_ASSERT(insn->op2 < IR_TRUE);
 			consts_count += ir_count_constant(_xlat, insn->op2);
 		} else if (insn->op == IR_CASE_RANGE) {
@@ -1255,7 +1260,7 @@ restart:
 						const char *proto = ir_get_strl(ctx, new_insn->proto, &len);
 						new_insn->proto = ir_strl(&new_ctx, proto, len);
 					}
-				} else if (new_insn->op == IR_SYM || new_insn->op == IR_STR) {
+				} else if (new_insn->op == IR_SYM || new_insn->op == IR_STR || new_insn->op == IR_LABEL) {
 					size_t len;
 					const char *str = ir_get_strl(ctx, new_insn->val.name, &len);
 					new_insn->val.u64 = ir_strl(&new_ctx, str, len);
@@ -1292,7 +1297,7 @@ restart:
 				} else {
 					new_insn->proto = 0;
 				}
-			} else if (insn->op == IR_SYM || insn->op == IR_STR) {
+			} else if (insn->op == IR_SYM || insn->op == IR_STR || insn->op == IR_LABEL) {
 				size_t len;
 				const char *str = ir_get_strl(ctx, insn->val.name, &len);
 				new_insn->val.u64 = ir_strl(&new_ctx, str, len);
@@ -1364,6 +1369,8 @@ restart:
 					size_t len;
 					const char *str = ir_get_strl(ctx, insn->op2, &len);
 					new_insn->op2 = ir_strl(&new_ctx, str, len);
+				} else if (new_insn->op == IR_BEGIN && insn->op2) {
+					new_insn->op2 = _xlat[insn->op2];
 				} else {
 					new_insn->op2 = insn->op2;
 				}
@@ -1379,6 +1386,8 @@ restart:
 					switch (new_insn->op) {
 						case IR_EQ:
 						case IR_NE:
+						case IR_ORDERED:
+						case IR_UNORDERED:
 						case IR_ADD:
 						case IR_MUL:
 						case IR_ADD_OV:
