@@ -175,15 +175,15 @@ failure:
 	function2 = Z_PTR_P(t);
 	CG(in_compilation) = 1;
 	zend_set_compiled_filename(function1->op_array.filename);
-	CG(zend_lineno) = function1->op_array.opcodes[0].lineno;
+	CG(zend_lineno) = function1->op_array.line_start;
 	if (function2->type == ZEND_USER_FUNCTION
 		&& function2->op_array.last > 0) {
-		zend_error(E_ERROR, "Cannot redeclare %s() (previously declared in %s:%d)",
+		zend_error_noreturn(E_ERROR, "Cannot redeclare function %s() (previously declared in %s:%d)",
 				   ZSTR_VAL(function1->common.function_name),
 				   ZSTR_VAL(function2->op_array.filename),
-				   (int)function2->op_array.opcodes[0].lineno);
+				   (int)function2->op_array.line_start);
 	} else {
-		zend_error(E_ERROR, "Cannot redeclare %s()", ZSTR_VAL(function1->common.function_name));
+		zend_error_noreturn(E_ERROR, "Cannot redeclare function %s()", ZSTR_VAL(function1->common.function_name));
 	}
 }
 
@@ -227,9 +227,7 @@ static zend_always_inline void _zend_accel_class_hash_copy(HashTable *target, Ha
 					CG(in_compilation) = 1;
 					zend_set_compiled_filename(ce1->info.user.filename);
 					CG(zend_lineno) = ce1->info.user.line_start;
-					zend_error(E_ERROR,
-							"Cannot declare %s %s, because the name is already in use",
-							zend_get_object_type(ce1), ZSTR_VAL(ce1->name));
+					zend_class_redeclaration_error(E_ERROR, Z_PTR_P(t));
 					return;
 				}
 				continue;
