@@ -1202,12 +1202,12 @@ static HashTable *sxe_get_properties(zend_object *object) /* {{{ */
 }
 /* }}} */
 
-static HashTable * sxe_get_debug_info(zend_object *object, int *is_temp) /* {{{ */
+/* This custom handler exists because the var_dump adds a pseudo "@attributes" key. */
+PHP_METHOD(SimpleXMLElement, __debugInfo)
 {
-	*is_temp = 1;
-	return sxe_get_prop_hash(object, 1);
+	ZEND_PARSE_PARAMETERS_NONE();
+	RETURN_ARR(sxe_get_prop_hash(Z_OBJ_P(ZEND_THIS), 1));
 }
-/* }}} */
 
 static int sxe_objects_compare(zval *object1, zval *object2) /* {{{ */
 {
@@ -1529,10 +1529,10 @@ static void sxe_add_registered_namespaces(php_sxe_object *sxe, xmlNodePtr node,
 				/* Attributes in the xmlns namespace should be treated as namespace declarations too. */
 				if (attr->ns && xmlStrEqual(attr->ns->href, (const xmlChar *) "http://www.w3.org/2000/xmlns/")) {
 					const char *prefix = attr->ns->prefix ? (const char *) attr->name : "";
-					bool free;
-					xmlChar *href = php_libxml_attr_value(attr, &free);
+					bool should_free;
+					xmlChar *href = php_libxml_attr_value(attr, &should_free);
 					sxe_add_namespace_name_raw(return_value, prefix, (const char *) href);
-					if (free) {
+					if (should_free) {
 						xmlFree(href);
 					}
 				}
@@ -1629,7 +1629,7 @@ PHP_METHOD(SimpleXMLElement, getName)
 	node = php_sxe_get_first_node_non_destructive(sxe, node);
 	if (node) {
 		namelen = xmlStrlen(node->name);
-		RETURN_STRINGL((char*)node->name, namelen);
+		RETURN_STRINGL_FAST((const char *) node->name, namelen);
 	} else {
 		RETURN_EMPTY_STRING();
 	}
@@ -2682,7 +2682,6 @@ PHP_MINIT_FUNCTION(simplexml)
 	sxe_object_handlers.compare = sxe_objects_compare;
 	sxe_object_handlers.cast_object = sxe_object_cast;
 	sxe_object_handlers.count_elements = sxe_count_elements;
-	sxe_object_handlers.get_debug_info = sxe_get_debug_info;
 	sxe_object_handlers.get_closure = NULL;
 	sxe_object_handlers.get_gc = sxe_get_gc;
 
